@@ -65,7 +65,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
 
     lino_web_template = "react/linoweb.json"
     file_type = '.json'
-    hide_dashboard_items = True  # Used to prevent any dashboard items being rendered from main html dashboard.
+    support_dashboard_layout = True  # Used to prevent any dashboard items being rendered from main html dashboard.
 
     def __init__(self, front_end):
         JsRenderer.__init__(self, front_end)
@@ -99,10 +99,16 @@ class Renderer(JsRenderer, JsCacheRenderer):
             menu=settings.SITE.get_site_menu(get_user_profile()),
             suggestors=list(plugins.memo.parser.suggesters.keys()),  # [#,@] keytriggers
             use_dashboard_layouts=plugins.system.use_dashboard_layouts,
+            site_title=settings.SITE.title,
             )
 
+        if hasattr(settings.SITE, 'theme_name'):
+            data.update(theme_name=settings.SITE.theme_name)
+
         if settings.SITE.user_model == None:
             data.update(no_user_model=True)
+        elif hasattr(plugins.users, 'allow_online_registration'):
+            data.update(allow_online_registration=plugins.users.allow_online_registration)
 
         if settings.SITE.is_installed('notify'):
             data.update(use_push_api=plugins.notify.use_push_api)
