@@ -6,6 +6,7 @@
 """
 
 from os import environ
+import datetime
 import re
 import cgi
 import ast
@@ -20,6 +21,7 @@ from django.conf import settings
 from django.views.generic import View
 from django.views.generic.base import TemplateView
 from django.core import exceptions
+from django.utils import timezone
 from django.utils.translation import gettext as _
 from django.utils.translation import get_language
 from django.core.exceptions import PermissionDenied
@@ -106,6 +108,7 @@ class ApiElement(ApiElement):
 class ApiList(View):
     def post(self, request, app_label=None, actor=None):
         ar = action_request(app_label, actor, request, request.POST, True)
+        ar.get_status()
         ar.renderer = settings.SITE.kernel.default_renderer
         return settings.SITE.kernel.run_action(ar)
 
@@ -631,15 +634,20 @@ class UserSettings(View):
 
         def getit():
             # print(20200419, settings.SITE.build_media_url(*settings.SITE.plugins.react.renderer.lino_js_parts()))
-            if not settings.SITE.build_js_cache_on_startup:
+            if (not settings.SITE.build_js_cache_on_startup
+                and not settings.SITE.never_build_site_cache):
                 settings.SITE.plugins.react.renderer.build_js_cache(False)
+                separate_site_cache_root = False
+            else:
+                separate_site_cache_root = True
             user_settings = dict(
                 user_type=u.user_type,
                 dashboard_items=len(u.get_preferences().dashboard_items),
+                email=u.email,
                 # [d.serialize() for d in u.get_preferences().dashboard_items],
                 lv=str(settings.SITE.kernel.code_mtime),
                 lang=get_language(),
-                site_data=settings.SITE.build_media_url(*settings.SITE.plugins.react.renderer.lino_js_parts()),
+                site_data=settings.SITE.build_site_cache_url(*settings.SITE.plugins.react.renderer.lino_js_parts()),
                 logged_in=not_anon,
                 username=u.get_full_name() if not_anon else _("Anonymous"),
                 su_name=su_name,  # subst_user # must be passed as param in get_user_settings request,
@@ -651,6 +659,9 @@ class UserSettings(View):
                 my_setting_text=_("My settings"),
                 user_id=u.pk,
             )
+            if separate_site_cache_root:
+                user_settings['separate_site_cache_root'] = True
+
             if su_name:
                 user_settings["user_id"] = user_settings["su_id"] = su.id
                 user_settings["su_user_type"] = su.user_type
@@ -659,6 +670,18 @@ class UserSettings(View):
                 user_settings["authorities"] = u.get_authorities()
                 user_settings["dashboard_layout"] = u.dashboard_layout
 
+                if settings.SITE.plugins.users.allow_online_registration:
+                    require_verification = not u.is_verified()
+                    if require_verification:
+                        user_settings['require_verification'] = True
+                        expiry_time = (u.verification_code_sent_on + datetime.timedelta(
+                            minutes=settings.SITE.plugins.users.verification_code_expires
+                        ))
+                        with timezone.override('UTC'):
+                            expiry_stamp = datetime.datetime.timestamp(
+                                timezone.make_naive(expiry_time))
+                        user_settings['code_expiry'] = expiry_stamp
+
             return json_response(user_settings)
 
         return with_user_profile((su or u).user_type, getit)
